==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridColumnGroupOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnGroupOptionsDescription } from "./GridColumnGroupOptionsDescription";
/**
 * @hidden
 */
export let GridColumnGroupOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnGroupOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnGroupOptionsDescriptionMetadata.a == null) {
                GridColumnGroupOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnGroupOptionsDescriptionMetadata.c(GridColumnGroupOptionsDescriptionMetadata.a);
            }
            if (a.j(GridColumnGroupOptionsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridColumnGroupOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GridColumnGroupOptionsDescriptionMetadata.b(a);
            a.aa("GridColumnGroupOptions", () => new GridColumnGroupOptionsDescription());
            a.z("GridColumnGroupOptions", GridColumnGroupOptionsDescriptionMetadata.a);
        }
    }
    GridColumnGroupOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnGroupOptionsDescriptionMetadata, 'GridColumnGroupOptionsDescriptionMetadata');
    GridColumnGroupOptionsDescriptionMetadata.a = null;
    return GridColumnGroupOptionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridColumnGroupOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnGroupOptionsDescription } from "./GridColumnGroupOptionsDescription";
/**
 * @hidden
 */
export let GridColumnGroupOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnGroupOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnGroupOptionsDescriptionMetadata.a == null) {
                GridColumnGroupOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnGroupOptionsDescriptionMetadata.c(GridColumnGroupOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnGroupOptionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridColumnGroupOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GridColumnGroupOptionsDescriptionMetadata.b(a);
            a.ac("GridColumnGroupOptions", () => new GridColumnGroupOptionsDescription());
            a.ab("GridColumnGroupOptions", GridColumnGroupOptionsDescriptionMetadata.a);
        }
    }
    GridColumnGroupOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnGroupOptionsDescriptionMetadata, 'GridColumnGroupOptionsDescriptionMetadata');
    GridColumnGroupOptionsDescriptionMetadata.a = null;
    return GridColumnGroupOptionsDescriptionMetadata;
})();
